summaryrefslogtreecommitdiff
path: root/beta_accents/app/include/ludo/html_elements.inc.php
diff options
context:
space:
mode:
Diffstat (limited to 'beta_accents/app/include/ludo/html_elements.inc.php')
-rw-r--r--beta_accents/app/include/ludo/html_elements.inc.php26
1 files changed, 13 insertions, 13 deletions
diff --git a/beta_accents/app/include/ludo/html_elements.inc.php b/beta_accents/app/include/ludo/html_elements.inc.php
index b845f28..35eaa68 100644
--- a/beta_accents/app/include/ludo/html_elements.inc.php
+++ b/beta_accents/app/include/ludo/html_elements.inc.php
@@ -1,6 +1,6 @@
<?php
/*
* Fonctions de génération de code HTML...
*/
function generate_html_doctype_and_head($title)
{
@@ -10,9 +10,9 @@ echo '<?xml version="1.0" encoding="ISO-8859-1"?>'."\n"
<html xmlns="http://www.w3.org/1999/xhtml" lang="fr">
<head>
<?php echo "<title>AWOR - $title</title>\n"; ?>
- <meta name="keywords" content="AWOR, Application Web, Organisation, Réunion, Reunion" />
- <meta name="description" content="Application Web d'Organisation de Réunion (AWOR). Facilite la vie des organisateurs !" />
- <meta name="author" content="Jérémie Dénoyer, Ludovic Pouzenc, Andriana Semouchtchak, Julien Sérè" />
+ <meta name="keywords" content="AWOR, Application Web, Organisation, R&eacute;union, Reunion" />
+ <meta name="description" content="Application Web d'Organisation de R&eacute;union (AWOR). Facilite la vie des organisateurs !" />
+ <meta name="author" content="J&eacute;r&eacute;mie D&eacute;noyer, Ludovic Pouzenc, Andriana Semouchtchak, Julien S&eacute;r&egrave;" />
<script type="text/javascript" src="script.js"></script>
<?php
//print_r($_COOKIE['aworcustom_css']);
@@ -88,7 +88,7 @@ function generate_html_div_errmsg($errmsg)
require_once('config.inc.php');
if ( isset( $CONFIG['adminMail'] ) && ( ! isset($_REQUEST['debug'] ) ) )
{
- echo '<span class="contactAdm">Si le problème persiste, vous pouvez contacter l\'administrateur par email à l\'adresse suivante : ';
+ echo '<span class="contactAdm">Si le probl&egrave;me persiste, vous pouvez contacter l\'administrateur par email &agrave; l\'adresse suivante : ';
echo '<a href="mailto:' . $CONFIG['adminMail'] . '">' . $CONFIG['adminMail'] . "</a></span>\n";
}
echo "</div>\n";
@@ -109,7 +109,7 @@ function generate_html_div_css_chooser()
{
echo ' <option value="' . $file . '"';
if ( $file == $css_selected ) { echo ' selected="selected"'; }
- echo '>' . $name . '</option>' /*. "$DEBUG:file=$file, css_selected=$css_selected"*/ . "\n";
+ echo '>' . htmlentities($name, ENT_QUOTES) . '</option>' /*. "$DEBUG:file=$file, css_selected=$css_selected"*/ . "\n";
}
echo ' </select>'. "\n";
echo '</div>'. "\n";
@@ -124,18 +124,18 @@ function generate_html_div_footer()
<?php generate_html_div_css_chooser(); ?>
</li>
<li class="center">
- <a href="http://validator.w3.org/check/referer" target="_blank">
- <img src="./images/vxhtml.gif" alt="Validate" border="0" height="31" width="88" />
+ <a href="http://validator.w3.org/check/referer">
+ <img src="./images/vxhtml.gif" alt="Validate" height="31" width="88" />
</a>
- <a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank">
- <img src="./images/vcss.gif" alt="Validate" border="0" height="31" width="88" />
+ <a href="http://jigsaw.w3.org/css-validator/check/referer">
+ <img src="./images/vcss.gif" alt="Validate" height="31" width="88" />
</a>
- <a href="http://www.w3.org/WAI/WCAG1A-Conformance" title="Explanation of Level A Conformance" target="_blank">
- <img src="./images/wai.gif" alt="W3C-WAI level A conformance icon" border="0" height="31" width="88" />
+ <a href="http://www.w3.org/WAI/WCAG1A-Conformance">
+ <img src="./images/wai.gif" alt="W3C-WAI level A conformance icon" height="31" width="88" />
</a>
</li>
<li class="right">
- <span class="discret">Application réalisée par Jérémie Dénoyer,<br /> Ludovic Pouzenc, Julien Séré et Andriana Semouchtchak</span>
+ <span class="discret">Application r&eacute;alis&eacute;e par J&eacute;r&eacute;mie D&eacute;noyer,<br /> Ludovic Pouzenc, Julien S&eacute;r&eacute; et Andriana Semouchtchak</span>
</li>
</ul>
</div>
@@ -1,6 +1,6 @@
<?php
/*
- * Fonctions de génération de code HTML...
+ * Fonctions de g&eacute;n&eacute;ration de code HTML...
*/
function generate_html_doctype_and_head($title)